@@ -59,8 +59,12 @@
 /* relative plugin's rc filename (printf format) */
 #define PANEL_PLUGIN_RC_RELATIVE_PATH PANEL_PLUGIN_RELATIVE_PATH G_DIR_SEPARATOR_S "%s-%d.rc"
 
-/* xfconf property base (printf format) */
-#define PANEL_PLUGIN_PROPERTY_BASE "/plugins/plugin-%d"
+/* xfconf properties for panels and plugins */
+#define PANELS_PROPERTY_PREFIX "/panels"
+#define PANELS_PROPERTY_BASE PANELS_PROPERTY_PREFIX "/panel-%d"
+#define PLUGINS_PROPERTY_PREFIX "/plugins"
+#define PLUGINS_PROPERTY_BASE PLUGINS_PROPERTY_PREFIX "/plugin-%d"
+#define PLUGIN_IDS_PROPERTY_BASE PANELS_PROPERTY_BASE "/plugin-ids"
 
 /* minimum time in seconds between automatic restarts of panel plugins
  * without asking the user what to do */
@@ -137,4 +141,22 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
+#ifdef WNCK_TYPE_SCREEN
+static inline WnckScreen *
+panel_wnck_screen_get (int index)
+{
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  return wnck_screen_get (index);
+G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
+static inline WnckScreen *
+panel_wnck_screen_get_default (void)
+{
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  return wnck_screen_get_default ();
+G_GNUC_END_IGNORE_DEPRECATIONS
+}
+#endif
+
 #endif /* !__PANEL_PRIVATE_H__ */
