@@ -1780,7 +1780,7 @@ xfce_panel_plugin_get_property_base (XfcePanelPlugin *plugin)
 
   /* create the propert if needed */
   if (plugin->priv->property_base == NULL)
-    plugin->priv->property_base = g_strdup_printf (PANEL_PLUGIN_PROPERTY_BASE,
+    plugin->priv->property_base = g_strdup_printf (PLUGINS_PROPERTY_BASE,
                                                    plugin->priv->unique_id);
 
   return plugin->priv->property_base;
@@ -2502,6 +2502,9 @@ xfce_panel_plugin_arrow_type (XfcePanelPlugin *plugin)
  * relative to @attach_widget. If @attach_widget is NULL, the computed
  * position will be relative to @plugin.
  *
+ * Note that if the panel is hidden (autohide), you should delay calling this
+ * function until the panel is shown, so that it returns the correct coordinates.
+ *
  * This function is intended for custom menu widgets.
  * For a regular #GtkMenu you should use xfce_panel_plugin_popup_menu() instead.
  *
@@ -2557,26 +2560,6 @@ xfce_panel_plugin_position_widget (XfcePanelPlugin *plugin,
        *y += py;
     }
 
-  /* if the panel is hidden (auto hide is enabled) and we requested a
-   * panel lock, wait for gtk to position the panel before we actually
-   * use the coordinates */
-  if (plugin->priv->panel_lock > 0)
-    {
-      gint64 end_t = g_get_monotonic_time () + G_USEC_PER_SEC / 2;
-
-      while (*x == -9999 && *y == -9999)
-        {
-          while (gtk_events_pending ())
-            gtk_main_iteration ();
-
-          gdk_window_get_position (gtk_widget_get_window (attach_widget), x, y);
-
-          /* don't try longer then 1/2 a second */
-          if (g_get_monotonic_time () > end_t)
-            break;
-        }
-    }
-
   /* add the widgets allocation */
   gtk_widget_get_allocation (attach_widget, &alloc);
   *x += alloc.x;
@@ -2692,6 +2675,15 @@ xfce_panel_plugin_position_menu (GtkMenu  *menu,
 
 
 
+static gboolean
+xfce_panel_plugin_popup_menu_reposition (gpointer data)
+{
+  gtk_menu_reposition (data);
+  return FALSE;
+}
+
+
+
 /**
  * xfce_panel_plugin_popup_menu:
  * @plugin        : an #XfcePanelPlugin.
@@ -2729,32 +2721,24 @@ xfce_panel_plugin_popup_menu (XfcePanelPlugin *plugin,
   /* check if conditions are met to pop up menu at widget */
   if (widget != NULL)
     {
-      switch (plugin->priv->screen_position)
+      switch (xfce_panel_plugin_arrow_type (plugin))
         {
-          case XFCE_SCREEN_POSITION_NW_H:
-          case XFCE_SCREEN_POSITION_N:
-          case XFCE_SCREEN_POSITION_NE_H:
+          case GTK_ARROW_DOWN:
             widget_anchor = GDK_GRAVITY_SOUTH_WEST;
             menu_anchor = GDK_GRAVITY_NORTH_WEST;
             break;
 
-          case XFCE_SCREEN_POSITION_NW_V:
-          case XFCE_SCREEN_POSITION_W:
-          case XFCE_SCREEN_POSITION_SW_V:
+          case GTK_ARROW_RIGHT:
             widget_anchor = GDK_GRAVITY_NORTH_EAST;
             menu_anchor = GDK_GRAVITY_NORTH_WEST;
             break;
 
-          case XFCE_SCREEN_POSITION_NE_V:
-          case XFCE_SCREEN_POSITION_E:
-          case XFCE_SCREEN_POSITION_SE_V:
+          case GTK_ARROW_LEFT:
             widget_anchor = GDK_GRAVITY_NORTH_WEST;
             menu_anchor = GDK_GRAVITY_NORTH_EAST;
             break;
 
-          case XFCE_SCREEN_POSITION_SW_H:
-          case XFCE_SCREEN_POSITION_S:
-          case XFCE_SCREEN_POSITION_SE_H:
+          case GTK_ARROW_UP:
             widget_anchor = GDK_GRAVITY_NORTH_WEST;
             menu_anchor = GDK_GRAVITY_SOUTH_WEST;
             break;
@@ -2770,6 +2754,9 @@ xfce_panel_plugin_popup_menu (XfcePanelPlugin *plugin,
   /* register the menu */
   xfce_panel_plugin_register_menu (plugin, menu);
 
+  /* since we requested a panel lock, queue a menu repositioning in case the panel is hidden */
+  g_idle_add (xfce_panel_plugin_popup_menu_reposition, menu);
+
   /* pop up the menu */
   if (popup_at_widget)
     gtk_menu_popup_at_widget (menu, widget, widget_anchor, menu_anchor, trigger_event);
