@@ -298,6 +298,7 @@ panel_base_window_set_property (GObject      *object,
   PanelBgStyle            bg_style;
   GFile                  *file;
   gdouble                 opacity;
+  const gchar            *str;
 
   switch (prop_id)
     {
@@ -374,11 +375,17 @@ panel_base_window_set_property (GObject      *object,
       break;
 
     case PROP_BACKGROUND_IMAGE:
-      /* store new uri, built and escaped through a GFile */
       g_free (window->background_image);
-      file = g_file_new_for_commandline_arg (g_value_get_string (value));
-      window->background_image = g_file_get_uri (file);
-      g_object_unref (file);
+      str = g_value_get_string (value);
+      if (str != NULL)
+        {
+          /* store new uri, built and escaped through a GFile */
+          file = g_file_new_for_commandline_arg (str);
+          window->background_image = g_file_get_uri (file);
+          g_object_unref (file);
+        }
+      else
+        window->background_image = NULL;
 
       if (window->background_style == PANEL_BG_STYLE_IMAGE)
         {
@@ -457,9 +464,11 @@ panel_base_window_screen_changed (GtkWidget *widget, GdkScreen *previous_screen)
   /* set the rgba colormap if supported by the screen */
   screen = gtk_window_get_screen (GTK_WINDOW (window));
   visual = gdk_screen_get_rgba_visual (screen);
-  window->is_composited = gdk_screen_is_composited (screen);
-  if (visual != NULL && window->is_composited)
-    gtk_widget_set_visual (widget, visual);
+  if (visual != NULL)
+    {
+      gtk_widget_set_visual (widget, visual);
+      window->is_composited = gdk_screen_is_composited (screen);
+    }
 
    panel_debug (PANEL_DEBUG_BASE_WINDOW,
                "%p: rgba visual=%p, compositing=%s", window,
