@@ -68,12 +68,12 @@ struct _PanelBaseWindow
 
   PanelBgStyle             background_style;
   GdkRGBA                 *background_rgba;
-  GdkColor                *background_color;
   gchar                   *background_image;
 
   /* transparency settings */
   gdouble                  enter_opacity;
   gdouble                  leave_opacity;
+  gboolean                 opacity_is_enter;
 };
 
 GType        panel_base_window_get_type                    (void) G_GNUC_CONST;
@@ -90,6 +90,8 @@ void         panel_base_window_orientation_changed         (PanelBaseWindow *win
 void         panel_base_window_set_borders                 (PanelBaseWindow *window,
                                                             PanelBorders     borders);
 PanelBorders panel_base_window_get_borders                 (PanelBaseWindow *window);
+void         panel_base_window_opacity_enter               (PanelBaseWindow *window,
+                                                            gboolean         enter);
 
 G_END_DECLS
 
