@@ -64,6 +64,7 @@ panel_dbus_client_get_proxy (GError **error)
 
 gboolean
 panel_dbus_client_display_preferences_dialog (guint         active,
+                                              guint         socket_id,
                                               GError      **error)
 {
   XfcePanelExportedService *dbus_proxy;
@@ -77,6 +78,7 @@ panel_dbus_client_display_preferences_dialog (guint         active,
 
   result = xfce_panel_exported_service_call_display_preferences_dialog_sync (dbus_proxy,
                                                                              active,
+                                                                             socket_id,
                                                                              NULL,
                                                                              error);
 
