@@ -67,9 +67,8 @@ struct _ApplicationsMenuPlugin
   gboolean         custom_menu;
   gchar           *custom_menu_file;
   gchar           *menu_editor;
-  guint            menu_reposition_idle_id;
 
-  gulong           style_set_id;
+  gulong           style_updated_id;
   gulong           screen_changed_id;
   gulong           theme_changed_id;
 };
@@ -254,8 +253,8 @@ applications_menu_plugin_init (ApplicationsMenuPlugin *plugin)
   g_signal_connect (G_OBJECT (plugin->menu), "selection-done",
       G_CALLBACK (applications_menu_plugin_menu_selection_done), plugin);
 
-  plugin->style_set_id = g_signal_connect_swapped (G_OBJECT (plugin->button), "style-set",
-                                                   G_CALLBACK (applications_menu_button_theme_changed), plugin);
+  plugin->style_updated_id = g_signal_connect_swapped (G_OBJECT (plugin->button), "style-updated",
+                                                       G_CALLBACK (applications_menu_button_theme_changed), plugin);
   plugin->screen_changed_id = g_signal_connect_swapped (G_OBJECT (plugin->button), "screen-changed",
                                                         G_CALLBACK (applications_menu_button_theme_changed), plugin);
   plugin->theme_changed_id = g_signal_connect_swapped (G_OBJECT (icon_theme), "changed",
@@ -474,16 +473,13 @@ applications_menu_plugin_free_data (XfcePanelPlugin *panel_plugin)
   ApplicationsMenuPlugin *plugin = XFCE_APPLICATIONS_MENU_PLUGIN (panel_plugin);
   GtkIconTheme           *icon_theme;
 
-  if (plugin->menu_reposition_idle_id != 0)
-    g_source_remove (plugin->menu_reposition_idle_id);
-
   if (plugin->menu != NULL)
     gtk_widget_destroy (plugin->menu);
 
-  if (plugin->style_set_id != 0)
+  if (plugin->style_updated_id != 0)
     {
-      g_signal_handler_disconnect (plugin->button, plugin->style_set_id);
-      plugin->style_set_id = 0;
+      g_signal_handler_disconnect (plugin->button, plugin->style_updated_id);
+      plugin->style_updated_id = 0;
     }
 
   if (plugin->screen_changed_id != 0)
@@ -550,7 +546,8 @@ applications_menu_plugin_size_changed (XfcePanelPlugin *panel_plugin,
     icon_theme = gtk_icon_theme_get_for_screen (screen);
 
   xfce_panel_set_image_from_source (GTK_IMAGE (plugin->image), plugin->button_icon,
-                                    icon_theme, icon_size);
+                                    icon_theme, icon_size,
+                                    gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
 
   if (plugin->show_button_title &&
       mode == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
@@ -626,7 +623,8 @@ applications_menu_plugin_configure_plugin_icon_chooser (GtkWidget              *
 
       image = gtk_image_new ();
       xfce_panel_set_image_from_source (GTK_IMAGE (image), plugin->button_icon,
-                                        NULL, DIALOG_ICON_SIZE);
+                                        NULL, DIALOG_ICON_SIZE,
+                                        gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
       gtk_container_remove (GTK_CONTAINER (button), gtk_bin_get_child (GTK_BIN (button)));
       gtk_container_add (GTK_CONTAINER (button), image);
       gtk_widget_show (image);
@@ -697,7 +695,8 @@ applications_menu_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 
   image = gtk_image_new ();
   xfce_panel_set_image_from_source (GTK_IMAGE (image), plugin->button_icon,
-                                    NULL, DIALOG_ICON_SIZE);
+                                    NULL, DIALOG_ICON_SIZE,
+                                    gtk_widget_get_scale_factor (GTK_WIDGET (plugin)));
   gtk_container_add (GTK_CONTAINER (object), image);
   gtk_widget_show (image);
 
@@ -843,19 +842,6 @@ applications_menu_plugin_set_garcon_menu (ApplicationsMenuPlugin *plugin)
 
 
 
-static gboolean
-applications_menu_plugin_menu_reposition (gpointer data)
-{
-  ApplicationsMenuPlugin *plugin = data;
-
-  gtk_menu_reposition (GTK_MENU (plugin->menu));
-  plugin->menu_reposition_idle_id = 0;
-
-  return FALSE;
-}
-
-
-
 static gboolean
 applications_menu_plugin_menu (GtkWidget              *button,
                                GdkEventButton         *event,
@@ -880,11 +866,6 @@ applications_menu_plugin_menu (GtkWidget              *button,
       event = g_slice_new0 (GdkEventButton);
       event->type = GDK_BUTTON_PRESS;
       event->window = gdk_get_default_root_window ();
-
-      /* reposition menu if popped up at widget and panel was autohidden when it was shown */
-      if (button != NULL)
-        plugin->menu_reposition_idle_id =
-          g_idle_add (applications_menu_plugin_menu_reposition, plugin);
     }
 
   xfce_panel_plugin_popup_menu (XFCE_PANEL_PLUGIN (plugin), GTK_MENU (plugin->menu),
