@@ -52,7 +52,7 @@
 
 /* Use the posix directory for the names. If people want a time based on posix or
  * right time, they can prepend that manually in the entry */
-#define ZONEINFO_DIR "/usr/share/zoneinfo/posix/"
+#define ZONEINFO_DIR "/usr/share/zoneinfo/"
 
 
 
@@ -179,13 +179,32 @@ static const gchar *tooltip_formats[] =
   NULL
 };
 
-static const gchar *digital_formats[] =
+static const gchar *digital_time_formats[] =
 {
-  DEFAULT_DIGITAL_FORMAT,
+  DEFAULT_DIGITAL_TIME_FORMAT,
   "%T",
-  "%r",
-  "%I:%M %p",
   "%_H:%M",
+  "%H:%M",
+  "%I:%M %p",
+  "%H:%M:%S",
+  "%l:%M:%S %P",
+  NULL
+};
+
+static const gchar *digital_date_formats[] =
+{
+  DEFAULT_DIGITAL_DATE_FORMAT,
+  "%Y %B %d",
+  "%m/%d/%Y",
+  "%B %d, %Y",
+  "%b %d, %Y",
+  "%d/%m/%Y",
+  "%d %B %Y",
+  "%d %b %Y",
+  "%A, %B %d, %Y",
+  "%a, %b %d, %Y",
+  "%A, %d %B %Y",
+  "%a, %d %b %Y",
   NULL
 };
 
@@ -274,7 +293,7 @@ clock_plugin_init (ClockPlugin *plugin)
   plugin->clock = NULL;
   plugin->tooltip_format = g_strdup (DEFAULT_TOOLTIP_FORMAT);
   plugin->tooltip_timeout = NULL;
-  plugin->command = NULL;
+  plugin->command = g_strdup ("");
   plugin->time_config_tool = g_strdup (DEFAULT_TIME_CONFIG_TOOL);
   plugin->rotate_vertically = TRUE;
   plugin->seat = NULL;
@@ -459,7 +478,7 @@ clock_plugin_button_press_event (GtkWidget      *widget,
 
           return TRUE;
         }
-      else if (event->type == GDK_2BUTTON_PRESS
+      else if (event->type == GDK_BUTTON_PRESS
                && !panel_str_is_empty (plugin->command))
         {
           /* launch command */
@@ -654,11 +673,15 @@ clock_plugin_configure_plugin_mode_changed (GtkComboBox       *combo,
     const gchar *property;
   } names[] = {
     { "show-seconds", "show-seconds", "active" },
-    { "binary-mode", "binary-mode", "active" },
+    { "binary-box", "binary-mode", "active" },
     { "show-military", "show-military", "active" },
     { "flash-separators", "flash-separators", "active" },
     { "show-meridiem", "show-meridiem", "active" },
-    { "digital-box", "digital-format", "text" },
+    { "digital-box", "digital-layout", "active" },
+    { "digital-box", "digital-date-format", "text" },
+    { "digital-box", "digital-time-format", "text" },
+    { "digital-box", "digital-date-font", "font-name" },
+    { "digital-box", "digital-time-font", "font-name" },
     { "fuzziness-box", "fuzziness", "value" },
     { "show-inactive", "show-inactive", "active" },
     { "show-grid", "show-grid", "active" },
@@ -677,15 +700,15 @@ clock_plugin_configure_plugin_mode_changed (GtkComboBox       *combo,
       break;
 
     case CLOCK_PLUGIN_MODE_BINARY:
-      active = 1 << 1 | 1 << 2 | 1 << 8 | 1 << 9;
+      active = 1 << 1 | 1 << 2 | 1 << 12 | 1 << 13;
       break;
 
     case CLOCK_PLUGIN_MODE_DIGITAL:
-      active = 1 << 6;
+      active = 1 << 6 | 1 << 7 | 1 << 8 | 1 << 9 | 1 << 10;
       break;
 
     case CLOCK_PLUGIN_MODE_FUZZY:
-      active = 1 << 7;
+      active = 1 << 11;
       break;
 
     case CLOCK_PLUGIN_MODE_LCD:
@@ -730,6 +753,52 @@ clock_plugin_configure_plugin_mode_changed (GtkComboBox       *combo,
 
 
 
+static void
+clock_plugin_digital_layout_changed (GtkComboBox       *combo,
+                                     ClockPluginDialog *dialog)
+{
+  guint    mode;
+  GObject *date_box, *time_box;
+
+  panel_return_if_fail (GTK_IS_COMBO_BOX (combo));
+  panel_return_if_fail (GTK_IS_BUILDER (dialog->builder));
+  panel_return_if_fail (XFCE_IS_CLOCK_PLUGIN (dialog->plugin));
+
+  date_box = gtk_builder_get_object (dialog->builder, "digital-date");
+  time_box = gtk_builder_get_object (dialog->builder, "digital-time");
+
+  /* the active items for each mode */
+  mode = gtk_combo_box_get_active (combo);
+  switch (mode)
+    {
+    case CLOCK_PLUGIN_DIGITAL_FORMAT_DATE:
+      gtk_widget_show (GTK_WIDGET (date_box));
+      gtk_widget_hide (GTK_WIDGET (time_box));
+      break;
+
+    case CLOCK_PLUGIN_DIGITAL_FORMAT_TIME:
+      gtk_widget_hide (GTK_WIDGET (date_box));
+      gtk_widget_show (GTK_WIDGET (time_box));
+      break;
+
+    case CLOCK_PLUGIN_DIGITAL_FORMAT_DATE_TIME:
+      gtk_widget_show (GTK_WIDGET (date_box));
+      gtk_widget_show (GTK_WIDGET (time_box));
+      break;
+
+    case CLOCK_PLUGIN_DIGITAL_FORMAT_TIME_DATE:
+      gtk_widget_show (GTK_WIDGET (date_box));
+      gtk_widget_show (GTK_WIDGET (time_box));
+      break;
+
+    default:
+      panel_assert_not_reached ();
+      break;
+    }
+}
+
+
+
 static void
 clock_plugin_configure_plugin_chooser_changed (GtkComboBox *combo,
                                                GtkEntry    *entry)
@@ -845,6 +914,45 @@ clock_plugin_validate_entry_tz (GtkEditable *entry,
 
 
 
+static gboolean
+clock_plugin_tz_match_func (GtkEntryCompletion *completion,
+                            const gchar *key,
+                            GtkTreeIter *iter,
+                            gpointer user_data)
+{
+  gchar *item = NULL;
+  gchar *normalized_string;
+  gchar *case_normalized_string;
+  GtkTreeModel *model;
+
+  gboolean ret = FALSE;
+
+  model = gtk_entry_completion_get_model (completion);
+
+  gtk_tree_model_get (model, iter, 0, &item, -1);
+
+  if (item != NULL)
+    {
+      normalized_string = g_utf8_normalize (item, -1, G_NORMALIZE_ALL);
+
+      if (normalized_string != NULL)
+        {
+          case_normalized_string = g_utf8_casefold (normalized_string, -1);
+
+          if (strstr (case_normalized_string, key))
+            ret = TRUE;
+
+          g_free (case_normalized_string);
+        }
+      g_free (normalized_string);
+    }
+  g_free (item);
+
+  return ret;
+}
+
+
+
 static void
 clock_plugin_configure_plugin_chooser_fill (ClockPlugin *plugin,
                                             GtkComboBox *combo,
@@ -980,6 +1088,9 @@ clock_plugin_configure_zoneinfo_model_insert (GtkListStore *store,
 
   panel_return_if_fail (GTK_IS_LIST_STORE (store));
 
+  if (g_str_has_suffix (parent, "posix") || g_str_has_suffix (parent, "right"))
+    return;
+
   dir = g_dir_open (parent, 0, NULL);
   if (dir == NULL)
     return;
@@ -1031,6 +1142,7 @@ clock_plugin_configure_zoneinfo_model (gpointer data)
 
   completion = gtk_entry_completion_new ();
   gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (store));
+  gtk_entry_completion_set_match_func (completion, clock_plugin_tz_match_func, NULL, NULL);
   g_object_unref (G_OBJECT (store));
 
   gtk_entry_set_completion (GTK_ENTRY (object), completion);
@@ -1105,14 +1217,33 @@ clock_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
                                               GTK_ENTRY (object),
                                               tooltip_formats);
 
-  object = gtk_builder_get_object (builder, "digital-format");
+  object = gtk_builder_get_object (builder, "command");
+  g_object_bind_property (G_OBJECT (plugin), "command",
+                          G_OBJECT (object), "text",
+                          G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+
+  object = gtk_builder_get_object (builder, "digital-layout");
+  g_signal_connect (G_OBJECT (object), "changed",
+      G_CALLBACK (clock_plugin_digital_layout_changed), dialog);
+  clock_plugin_digital_layout_changed (GTK_COMBO_BOX (object), dialog);
+
+  object = gtk_builder_get_object (builder, "digital-time-format");
   g_signal_connect (G_OBJECT (object), "changed",
                     G_CALLBACK (clock_plugin_validate_entry_text), plugin);
-  combo = gtk_builder_get_object (builder, "digital-chooser");
+  combo = gtk_builder_get_object (builder, "digital-time-chooser");
   clock_plugin_configure_plugin_chooser_fill (plugin,
                                               GTK_COMBO_BOX (combo),
                                               GTK_ENTRY (object),
-                                              digital_formats);
+                                              digital_time_formats);
+
+  object = gtk_builder_get_object (builder, "digital-date-format");
+  g_signal_connect (G_OBJECT (object), "changed",
+                    G_CALLBACK (clock_plugin_validate_entry_text), plugin);
+  combo = gtk_builder_get_object (builder, "digital-date-chooser");
+  clock_plugin_configure_plugin_chooser_fill (plugin,
+                                              GTK_COMBO_BOX (combo),
+                                              GTK_ENTRY (object),
+                                              digital_date_formats);
 
   gtk_widget_show (GTK_WIDGET (window));
 }
@@ -1122,7 +1253,7 @@ clock_plugin_configure_plugin (XfcePanelPlugin *panel_plugin)
 static void
 clock_plugin_set_mode (ClockPlugin *plugin)
 {
-  const PanelProperty properties[][5] =
+  const PanelProperty properties[][6] =
   {
     { /* analog */
       { "show-seconds", G_TYPE_BOOLEAN },
@@ -1136,7 +1267,11 @@ clock_plugin_set_mode (ClockPlugin *plugin)
       { NULL },
     },
     { /* digital */
-      { "digital-format", G_TYPE_STRING },
+      { "digital-layout", G_TYPE_UINT },
+      { "digital-time-format", G_TYPE_STRING },
+      { "digital-date-format", G_TYPE_STRING },
+      { "digital-time-font", G_TYPE_STRING },
+      { "digital-date-font", G_TYPE_STRING },
       { NULL },
     },
     { /* fuzzy */
@@ -1212,15 +1347,13 @@ clock_plugin_reposition_calendar (ClockPlugin *plugin)
 
 
 static void
-clock_plugin_calendar_realized (GtkWidget   *calendar_window,
-                                ClockPlugin *plugin)
+clock_plugin_calendar_show_event (GtkWidget   *calendar_window,
+                                  ClockPlugin *plugin)
 {
   GDateTime *time;
 
   panel_return_if_fail (XFCE_IS_PANEL_PLUGIN (plugin));
 
-  clock_plugin_reposition_calendar (plugin);
-
   time = clock_time_get_time (plugin->time);
   gtk_calendar_select_month (GTK_CALENDAR (plugin->calendar), g_date_time_get_month (time) - 1,
                              g_date_time_get_year (time));
@@ -1377,8 +1510,8 @@ clock_plugin_popup_calendar (ClockPlugin *plugin)
                                         GTK_CALENDAR_SHOW_HEADING
                                         | GTK_CALENDAR_SHOW_DAY_NAMES
                                         | GTK_CALENDAR_SHOW_WEEK_NUMBERS);
-      g_signal_connect (G_OBJECT (plugin->calendar_window), "realize",
-                        G_CALLBACK (clock_plugin_calendar_realized), plugin);
+      g_signal_connect (G_OBJECT (plugin->calendar_window), "show",
+                        G_CALLBACK (clock_plugin_calendar_show_event), plugin);
       g_signal_connect (G_OBJECT (plugin->calendar_window), "button-press-event",
                         G_CALLBACK (clock_plugin_calendar_button_press_event), plugin);
       g_signal_connect (G_OBJECT (plugin->calendar_window), "key-press-event",
@@ -1387,6 +1520,7 @@ clock_plugin_popup_calendar (ClockPlugin *plugin)
       gtk_widget_show (plugin->calendar);
     }
 
+  clock_plugin_reposition_calendar (plugin);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (plugin->button), TRUE);
   gtk_widget_show (GTK_WIDGET (plugin->calendar_window));
   xfce_panel_plugin_block_autohide (XFCE_PANEL_PLUGIN (plugin), TRUE);
