@@ -11,9 +11,9 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef __LAUNCHER_H__
@@ -59,6 +59,8 @@ gboolean    launcher_plugin_item_is_editable (LauncherPlugin      *plugin,
                                               GarconMenuItem      *item,
                                               gboolean            *can_delete);
 
+GIcon      *launcher_plugin_tooltip_icon     (const gchar         *icon_name);
+
 G_END_DECLS
 
 #endif /* !__LAUNCHER_H__ */
