@@ -104,6 +104,9 @@ struct _PagerPlugin
   GtkWidget     *pager;
 
   WnckScreen    *wnck_screen;
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  WnckHandle    *wnck_handle;
+#endif
 
   /* settings */
   guint          scrolling : 1;
@@ -215,6 +218,9 @@ pager_plugin_init (PagerPlugin *plugin)
   plugin->pager = NULL;
   plugin->sync_idle_id = 0;
   plugin->sync_wait = TRUE;
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  plugin->wnck_handle = wnck_handle_new (WNCK_CLIENT_TYPE_PAGER);
+#endif
 
   master_plugin = pager_plugin_get_master_plugin (plugin);
   if (master_plugin == NULL)
@@ -571,9 +577,13 @@ pager_plugin_screen_layout_changed (PagerPlugin *plugin)
     {
       pager_plugin_set_ratio (plugin);
 
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+#if WNCK_CHECK_VERSION (43, 0, 0)
+      /* using a handle allows in particular the pager not to be affected by a possible
+       * change of default wnck icon size in other plugins */
+      plugin->pager = wnck_pager_new_with_handle (plugin->wnck_handle);
+#else
       plugin->pager = wnck_pager_new ();
-G_GNUC_END_IGNORE_DEPRECATIONS
+#endif
       g_signal_connect_after (G_OBJECT (plugin->pager), "drag-begin",
                               G_CALLBACK (pager_plugin_drag_begin_event), plugin);
       g_signal_connect_after (G_OBJECT (plugin->pager), "drag-end",
@@ -681,6 +691,10 @@ pager_plugin_free_data (XfcePanelPlugin *panel_plugin)
   g_signal_handlers_disconnect_by_func (G_OBJECT (plugin),
       pager_plugin_screen_changed, NULL);
 
+#if WNCK_CHECK_VERSION (43, 0, 0)
+  g_object_unref (plugin->wnck_handle);
+#endif
+
   plugin_list = g_slist_remove (plugin_list, plugin);
   if (plugin->sync_idle_id != 0)
     g_source_remove (plugin->sync_idle_id);
