@@ -21,6 +21,7 @@
 #include <config.h>
 #endif
 
+#include <libwnck/libwnck.h>
 #include <libxfce4util/libxfce4util.h>
 #include <common/panel-private.h>
 #include <common/panel-utils.h>
@@ -156,7 +157,7 @@ show_desktop_plugin_screen_changed (GtkWidget *widget,
 
   /* get the new wnck screen */
   screen = gtk_widget_get_screen (widget);
-  wnck_screen = wnck_screen_get (panel_screen_get_number (screen));
+  wnck_screen = panel_wnck_screen_get (panel_screen_get_number (screen));
   panel_return_if_fail (WNCK_IS_SCREEN (wnck_screen));
 
   /* leave when the wnck screen did not change */
