@@ -54,10 +54,6 @@ GQuark          systray_manager_error_quark          (void);
 
 SystrayManager *systray_manager_new                  (void) G_GNUC_MALLOC;
 
-#if 0
-gboolean        systray_manager_check_running        (GdkScreen           *screen);
-#endif
-
 gboolean        systray_manager_register             (SystrayManager      *manager,
                                                       GdkScreen            *screen,
                                                       GError              **error);
@@ -65,10 +61,10 @@ gboolean        systray_manager_register             (SystrayManager      *manag
 void            systray_manager_unregister           (SystrayManager      *manager);
 
 void            systray_manager_set_colors           (SystrayManager *manager,
-                                                      GdkColor       *fg,
-                                                      GdkColor       *error,
-                                                      GdkColor       *warning,
-                                                      GdkColor       *success);
+                                                      GdkRGBA        *fg,
+                                                      GdkRGBA        *error,
+                                                      GdkRGBA        *warning,
+                                                      GdkRGBA        *success);
 
 void            systray_manager_set_orientation      (SystrayManager      *manager,
                                                       GtkOrientation       orientation);
