@@ -25,7 +25,6 @@ G_BEGIN_DECLS
 
 typedef struct _XfceTasklistClass     XfceTasklistClass;
 typedef struct _XfceTasklist          XfceTasklist;
-typedef enum   _XfceTasklistGrouping  XfceTasklistGrouping;
 typedef enum   _XfceTasklistSortOrder XfceTasklistSortOrder;
 typedef enum   _XfceTasklistMClick    XfceTasklistMClick;
 
@@ -38,17 +37,6 @@ typedef enum   _XfceTasklistMClick    XfceTasklistMClick;
 
 
 
-enum _XfceTasklistGrouping
-{
-  XFCE_TASKLIST_GROUPING_NEVER,
-  XFCE_TASKLIST_GROUPING_ALWAYS,
-  /*XFCE_TASKLIST_GROUPING_AUTO, *//* when space is limited */
-
-  XFCE_TASKLIST_GROUPING_MIN = XFCE_TASKLIST_GROUPING_NEVER,
-  XFCE_TASKLIST_GROUPING_MAX = XFCE_TASKLIST_GROUPING_ALWAYS,
-  XFCE_TASKLIST_GROUPING_DEFAULT = XFCE_TASKLIST_GROUPING_NEVER
-};
-
 enum _XfceTasklistSortOrder
 {
   XFCE_TASKLIST_SORT_ORDER_TIMESTAMP, /* sort by unique_id */
